
/**
 * Default Chart Controller.
 * This is the base controller for any chart components. All chart components will extend
 * this controller.
 * This controller does the work that is common in all charts.i.e to watch userChartConfig and update chart accordingly.
 */
import * as angular from 'angular';
import defaultChartConfig from './defaultChart-config';
import * as _ from 'lodash';
import * as Highcharts from 'highcharts';

export default class DefaultChartController{

    constructor($scope, $element, chartConfig){
        //Setting the reference to the domNode where chart will be drawn.
        //It can be accessed using firstChild as our template has only one domNode.
        var domNode:any = $element.get(0).firstChild;
        //merging passed-in user(consumer) chartConfig with defaultChartConfig and lineChartConfig.
        var mergedChartConfig:Highcharts.Options  = angular.merge({}, defaultChartConfig, chartConfig, this.getUserChartConfig());
        //setting the domNode where chart will be drawn(rendered).
        mergedChartConfig.chart.renderTo = domNode;
        //creating the chart with passed in config through HighChart constructor and setting it on 'chart' variable.
        var chart:Highcharts.ChartObject = new Highcharts.Chart(mergedChartConfig);
        //Watching on chartConfig.
        $scope.$watch(
            ()=> this.getUserChartConfig(),
            (newVal, oldVal)=>{
                //we update the config only when config exists and its not equal to older config.
                if(newVal && oldVal && !(_.isEqual(newVal, oldVal))){
                    //updating the current chartConfig with passed-in chartConfig.
                    angular.merge(mergedChartConfig, newVal);
                    //destroying the chart first before assigning the new object.
                    chart.destroy();
                    //creating the new chart.
                    chart = new Highcharts.Chart(mergedChartConfig);
                }
            },
        true);
    }

    getUserChartConfig():Highcharts.Options {
        throw Error("Child class must implement getUserChartConfig()");
    }
}
