import NwfValidator from '../nwfValidator';

class IsEmailValidatorController extends NwfValidator {

    static $inject = ['$element', '$i18next'];

    constructor(private $element: ng.IAugmentedJQuery, private $i18next) {
        super($element);
        this.myEl.setAttribute('type', 'email');
        this.myEl.setAttribute('multiple', 'multiple');
        this.invalidMessage = this.invalidMessage || $i18next.t('nwfjs:isEmailInvalidMessage');
        this.emptyMessage = this.emptyMessage || $i18next.t('nwfjs:emptyMessage');
    }

    invalidHandler() {
        if (this.myEl.validity.valueMissing && !this.myEl.validity.badInput) {
            this.myEl.setCustomValidity(this.emptyMessage);
        } else if (!this.myEl.validity.valid) {
            // if a semi-colon exists in the value of the textbox, we display comma-separated error.
            if (this.myEl.value.indexOf(';') > -1) {
                this.myEl.setCustomValidity(this.$i18next.t('nwfjs:isEmailMultipleInvalidMessage'));
            } else {
                this.myEl.setCustomValidity(this.invalidMessage);
            }
        } else {
            this.myEl.setCustomValidity('');
        }
    }
}

export class IsEmailValidator {

    static NAME: string = 'isEmail';
    bindToController = {
        emptyMessage: '@?',
        invalidMessage: '@?'
    };
    restrict = 'A';
    controller = IsEmailValidatorController;
    controllerAs = 'emailCtrl';
}

// export factory function
export function IsEmailValidatorFactory(): IsEmailValidator {
    return new IsEmailValidator();
}
