export default class NwfIconController {

    private isTwoColor: boolean;
    private indicatorClass: string;
    private backgroundClass: string;
    private iconClass: string;

    static $inject = [];
    static svgPrefix = 'svg-';

    constructor() {
    }

    get svgIconClass() {
        let iconClass = this.iconClass;
        /* if the iconClass doesnt end in -dims add it */
        let dimSuffix = '-dims';
        if (!(iconClass.indexOf(dimSuffix, iconClass.length - dimSuffix.length) !== -1)) {
            return iconClass + dimSuffix;
        }
        return iconClass;
    }

    get svgIconHref() {
        return '#' + this.iconClass.replace(NwfIconController.svgPrefix, '');
    }

    get isSvgIcon() {
        /* First I see if it starts with svg- */
        if (this.iconClass && this.iconClass.lastIndexOf(NwfIconController.svgPrefix, 0) === 0) {
            return true;
        }
        return false;
    }

    $onChanges() {
        var iconClass = this.iconClass;
        /* If we are an svg Icon I don't need two color font stuff */
        if (!iconClass || this.isSvgIcon) {
            return;
        }
        /* Now begin processing for font icon */

        /* gets the TwoColorBackgrounClass for this icon */
        function getTwoColorBackgroundClass(iconClass) {
            var stopSignIcon = 'icon-Critical-Error-Stop-Sign',
                circleIcon = 'icon-CircleBackGround',
                triangleIcon = 'icon-WarningTriangle';

            var twoColorIconBackgroundMap = {
                'icon-Critical-Full': stopSignIcon,
                'icon-Help': circleIcon,
                'icon-Error-Full': stopSignIcon,
                'icon-OkCircleWithCheck': circleIcon,
                'icon-Info': circleIcon,
                'icon-Warning': triangleIcon
            };

            if (iconClass in twoColorIconBackgroundMap) {
                return twoColorIconBackgroundMap[iconClass];
            }
            return undefined;
        }

        function getTwoColorIndicatorClass(iconClass) {
            var criticalIcon = 'icon-Critical-X',
                helpIcon = 'icon-QuestionMark',
                checkMarkIcon = 'icon-OkCheckMark',
                exclamationIcon = 'icon-Error-Exclamation',
                infoIcon = 'icon-i-Info';

            var twoColorIconIndicatorMap = {
                'icon-Critical-Full': criticalIcon,
                'icon-Help': helpIcon,
                'icon-Error-Full': exclamationIcon,
                'icon-OkCircleWithCheck': checkMarkIcon,
                'icon-Info': infoIcon,
                'icon-Warning': exclamationIcon
            };

            if (iconClass in twoColorIconIndicatorMap) {
                return twoColorIconIndicatorMap[iconClass];
            }
            return undefined;
        }

        /* Now I find out if it is a two color */
        this.isTwoColor = false;
        var iconCls = this.iconClass;
        var indicatorClass = getTwoColorIndicatorClass(iconCls);
        var backgroundClass = getTwoColorBackgroundClass(iconCls);

        if (indicatorClass && backgroundClass) {
            this.isTwoColor = true;
            this.indicatorClass = indicatorClass;
            this.backgroundClass = backgroundClass;
        } else {
            this.indicatorClass = iconCls;
        }
    }

}
