/**
 * This is the MathUtils object that provides static mathematical functions
 *
 * @author: Ulhas Pai
 **/

var MathUtils = {

    /**
     * @ngdoc function
     * @description
     * This methods rounds up a number based on how it needs to be displayed opn the UI.
     * Percent values :
     *      <1% ------ <1
     *      >1% ------ Round to a whole number
     *
     * Non Percent values :
     *      <1          ------ <1
     *      1 to 10     ------ Upto 2 decimal places
     *      10 to 100   ------ Upto 1 decimal places
     *      >100        ------ Round to a whole number
     *
     * @param value - the value to display
     * @param isPercent - whether the number is a percentage
     * @param statType - the statistic type of the value
     * @returns {*}
     */
    round: function (value, isPercent, statType) {

        isPercent = typeof isPercent !== 'undefined' ? isPercent : false;   //By default the isPercent = false
        statType = typeof statType !== 'undefined' ? statType : "";         //By default the statType = ""

        if (isPercent) {
            if (value === null) {   //  return null if null
                return null;
            } else if (value === 0) {
                return "0";
            } else if (value < 1) { // "<1" if < 1
                return "< 1";
            } else {    // Whole number otherwise
                return parseFloat(value).toFixed();
            }
        } else {
            if (value === null) {     // return null if null
                return null;
            } else if (value === 0) {
                return "0";
            } else if (value < 1) {
                switch (statType) {
                    case "latency":
                        return parseFloat(value).toFixed(3);   // 3 decimal points between 0 and 1 for Latency
                    default:
                        return "< 1";     // "<1" if < 1 for everything else
                }
            } else if (value < 10 && value >= 1) {    // 2 decimal points between 1 and 10
                return parseFloat(value).toFixed(2);
            } else if (value < 100 && value >= 10) {  // 1 decimal point between 10 and  100
                return parseFloat(value).toFixed(1);
            } else if (value >= 100) {   // Whole number if greater than 100
                return parseFloat(value).toFixed();
            } else {
                return value;
            }
        }
    }
};

export = MathUtils;