var StringUtils = {

    capitalize: function (value) {
        if (value && (typeof value === 'string')) {
            return value[0].toUpperCase() + value.slice(1).toLowerCase();
        } else {
            return value;
        }

    },

    properNoun: function (value, addIndefiniteArticle) {
        // Default is not to precede the proper noun with an indefinite article
        addIndefiniteArticle = typeof addIndefiniteArticle !== 'undefined' ? addIndefiniteArticle : false;

        if (value === null) {
            return null;
        }

        return (addIndefiniteArticle === true ? (/[aeiou]/i.test(value[0]) === true ? 'an ' : 'a ') : '') + this.capitalize(value);
    },

    /**
     * Converts Regular nouns to plural forms
     * *** Make sure that noun sent is "singular" otherwise, you may get unexpected results ***
     */
    pluralize: function (string) {

        /** This works for all regular nouns
         * Examples: Box --> boxes
         *  Policy --> policies
         *  Boat --> boats
         *  boat --> boats
         *  policy --> policies
         *  box --> boxes
         */

        if (string && (typeof string === 'string') && (string.length >= 2)) {

            //check for abbreviated words. Convert all to lower case except only when second alphabet is in Upper case.
            if (string.charAt(1) === string.charAt(1).toLocaleUpperCase()) {
                //don't convert to lower case.
            }
            else {
                //convert everything except first alphabet to lower case.
                string = string.charAt(0).toLocaleUpperCase() + string.substring(1).toLocaleLowerCase();
            }

            var lastEl = string.charAt(string.length - 1);
            var secondLastEl = string.charAt(string.length - 2);
            var lastTwoEl = secondLastEl + lastEl;

            //Some noun rules applied.
            if ((lastEl === 's' || lastEl === 'x' || lastEl === 'z') || (lastTwoEl === 'ch' || lastTwoEl === 'sh')) {

                return string + 'es';
            }
            else if ((this.isConsonant(secondLastEl)) && (lastEl === 'y')) {
                var temp = string.substring(0, string.length - 1);
                return temp + 'ies';
            }
            else {
                return string + 's';
            }
        }
        else {
            return string;
        }


    },

    isConsonant: function (str) {
        var vowels = ['a', 'e', 'i', 'o', 'u'];

        //evaluate only for javascript "truthy" values.
        if (str) {

            //returns true if the string passed is a consonant(non-vowel). For all vowels it returns false.
            return vowels.indexOf(str.toLowerCase()) === -1;
        }
        else
        //returning false for javascript "falsy" values.
            return false;
    }
};

export = StringUtils;